@@ -174,7 +174,7 @@ void programcmd(unsigned char seqnum)
                                 tmp = CONFIG_PARAM_OSC_CMATCH;
                                 break;
                         case PARAM_TOPCARD_DETECT: // stk500 only
-                                tmp = 0; // no card ??
+                                tmp = 0x8c; // no card ??
                                 break;
                         case PARAM_DATA: // stk500 only
                                 tmp = 0; 
